/*************************************************************************/
/* Title:       Diagnosis Group Systems (DGS) Load Software              */
/*                                                                       */
/* PROGRAM:     DGS_PROGRAM.SAS (Version date 7/9/2007)                  */
/*                                                                       */
/* Description: This program creates individual and multiple diagnosis   */ 
/*              look up tables for DGS categories for data using         */  
/*              ICD-9-CM diagnosis codes.                                */
/*                                                                       */
/*              There are three sections to this program:                */
/*                                                                       */
/*				I) The first section creates a MACRO for individual      */
/*				   diagnosis code look up. For a single code, the full   */
/*                 description, major group description, subgroup 	     */
/*                 description, combined common subgroup description and */
/*                 severity score are provided.                          */
/*              II) The second section creates a MACRO for multiple      */
/*                 diagnosis codes look up. Users can use this program   */
/*				   to map diagnosis codes into multilevel DGS categories */
/*				   for their own data set.                               */	
/*              III) The third section helps users to generate a         */
/*				   frequency PDF report based on the table from section  */
/*				   II. This PDF report will be automatically output onto */ 
/*                 your local C:\ or other designated drive.              */
/*************************************************************************/

/*************************************************************************/
/*Section I:   Individual Diagnosis Look Up Program                      */
/*			   This MACRO allows users to get full description, major    */
/*			   group, subgroup and combined commone subgroup description */
/*			   for an individual ICD9 code                                      */	
/*User enters:                                                           */
/*			   UniqueID = ID number for patient                          */	
/*             ICD9 = ICD-9-CM diagnosis codes                           */
/*					  (with leading zeros and without decimals)          */
/*************************************************************************/

%macro MyICD9_Code(UniqueID,ICD9);

	proc sql;
		create table MyICD9
  		(UniqueID char(100) label='Unique ID number',
    	ICD9_Code char(100) label='ICD-9-CM Code');
	quit;

	proc sql;
		insert into MyICD9
  	values(&UniqueID,&ICD9);
	quit;
	
	ods listing close;

	ods HTML;

	proc sql;
    	select a.UniqueID,
			   a.ICD9_Code, 
			   b.ICD9_Code_Desc ,
			   b.Major_Group_Desc,
			   b.Subgroup_Desc,
			   b.Combined_common_Subgroup,
			   b.Severity_score
    	from MyICD9 as a left join "C:\DGS\icd9_master" as b on a.ICD9_CODE=b.icd9_code;
	quit;
	
	ods HTML close;

%mend;

%MyICD9_Code(UniqueID='1789',ICD9='49310');

/*************************************************************************/
/*Section II:  Multiple Diagnoses Look Up Program                        */
/*		       This MACRO creates a SAS table "ICDcodes" which joins     */
/*             user's ICD9 list with ICD9_Master table and maps user's   */
/*             diagnosis codes into multilevel DGS categories. This      */
/*			   table can be used to add DGS categories to existing data  */
/*User enters:                                                           */
/*			   Dataset = The name of your dataset including ICD9 codes   */
/*             Var = Variable name indicating ICD9 code in your dataset  */
/*************************************************************************/

%macro Mydata(Dataset,Var);

	proc sql;
  		create table ICD9codes as
    	select *
      	from &dataset as a left join "C:\DGS\icd9_master" as b on a.&var=b.icd9_code;
	quit;
	
	data ICD9codes;
		set ICD9codes;
			array Check(1:6) VALIDITY ICD9_Code_Desc Major_Group_Desc Subgroup_Desc Combined_Common_Subgroup Severity_score;
			do i= 1 to 6;
			if ICD9_code = ' ' and &var ne ' ' then Check(i) = 'ICD-9 code not found';
		end;
		drop i;
	run;

%mend;

%Mydata(Dataset=DatasetName, Var=VariableofICD9code);*Please enter your dataset's name and variable's name; 

/*************************************************************************/
/*Section III: Frequency report                                          */
/*		       1) This MACRO creates a frequency PDF report based on the */
/*                table, "ICD9codes", created in Section II              */
/*             2) Before you run this section, you need to create a      */
/*                new folder on your C drive and replace the path name   */
/*                below (C:\YourFolderName\)                             */
/*************************************************************************/

proc freq data=icd9codes;
	tables major_group_desc*subgroup_desc/missing out=Count;
run;	

ods pdf file='C:\DGS\DGS frequency report.pdf';
ods noproctitle;

options pageno=1 linesize=200 pagesize=60 nodate;

title 'DGS Frequency Report';
title2 'Major Group by Subgroup';

proc report data=Count nowd split='\';
	column  Major_Group_Desc  Subgroup_Desc count percent;
	define Major_Group_Desc/order ;
run;

ods pdf close;
